var languageNames = {
"en-US": "Englisch (USA)",
"sq": "Albanisch",
"am": "Amharisch",
"ar": "Arabisch",
"ast": "Asturisch",
"bn": "Bengalisch",
"bn-IN": "Bengalisch (Indien)",
"bs": "Bosnisch",
"bg": "Bulgarisch",
"ca": "Katalanisch",
"ca-valencia": "Katalanisch (Valencia)",
"zh-CN": "Chinesisch (vereinfacht)",
"zh-TW": "Chinesisch (traditionell)",
"hr": "Kroatisch",
"cs": "Tschechisch",
"da": "Dänisch",
"nl": "Niederländisch",
"dz": "Dzongkha",
"en-GB": "Englisch (UK)",
"en-ZA": "Englisch (SA)",
"eo": "Esperanto",
"et": "Estnisch",
"eu": "Baskisch",
"fi": "Finnisch",
"fr": "Französisch",
"gl": "Galizisch",
"ka": "Georgisch",
"de": "Deutsch",
"el": "Griechisch",
"gu": "Gujaratisch",
"he": "Hebräisch",
"hi": "Hindi",
"hu": "Ungarisch",
"id": "Indonesisch",
"is": "Isländisch",
"it": "Italienisch",
"ja": "Japanisch",
"km": "Khmer",
"ko": "Koreanisch",
"lo": "Laotisch",
"lv": "Lettisch",
"lt": "Litauisch",
"mk": "Mazedonisch",
"ne": "Nepalesisch",
"nn": "Norwegisches Nynorsk",
"nb": "Norwegisches Bokmål",
"om": "Oromo",
"pl": "Polnisch",
"pt": "Portugiesisch",
"pt-BR": "Portugiesisch (Brasilien)",
"ro": "Rumänisch",
"ru": "Russisch",
"sid": "Sidama",
"si": "Singhalesisch",
"sk": "Slowakisch",
"sl": "Slowenisch",
"dsb": "Sorbian (Lower)",
"hsb": "Sorbian (Upper)",
"es": "Spanisch",
"sv": "Schwedisch",
"tg": "Tadschikisch",
"ta": "Tamilisch",
"bo": "Tibetisch",
"tr": "Türkisch",
"ug": "Uigurisch",
"uk": "Ukrainisch",
"vi": "Vietnamesisch",
};
